"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.testAll = exports.SystemTester = void 0;
const si = require("systeminformation");
const node_worker_threads_1 = require("node:worker_threads");
const test_all_1 = require("./test-all");
exports.testAll = test_all_1.default;
/**
 * Classe pour tester les performances du système et obtenir des informations système.
 */
class SystemTester {
    /**
     * Récupère les informations système détaillées telles que le processeur, la carte graphique, la RAM, le disque et le réseau.
     * @returns {Promise<SystemInfo>} Les informations système détaillées
     */
    static getSystemInfo() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            const cpu = yield si.cpu();
            const gpu = yield si.graphics();
            const ram = yield si.mem();
            const disk = yield si.diskLayout();
            const network = yield si.networkStats();
            const cpuInfo = {
                manufacturer: cpu.manufacturer,
                brand: cpu.brand,
                speed: cpu.speed,
                cores: cpu.cores,
                physicalCores: cpu.physicalCores,
                processors: cpu.processors,
                coresInfo: [],
            };
            // Récupérer les informations détaillées sur chaque cœur de processeur
            const cpuCores = yield si.cpuTemperature();
            for (let i = 0; i < cpuCores.max; i++) {
                cpuInfo.coresInfo.push({
                    logicalCores: cpuCores.cores.length,
                    frequency: cpu.speed,
                    load: (_a = cpuCores.socket) === null || _a === void 0 ? void 0 : _a[i],
                });
            }
            return {
                cpu: cpuInfo,
                gpu: {
                    manufacturer: gpu.controllers[0].vendor,
                    model: gpu.controllers[0].model,
                    memoryTotal: gpu.controllers[0].memoryTotal || 0 / 1024, // Convertir MB en Go
                    memoryUsed: gpu.controllers[0].memoryUsed || 0 / 1024,
                    memoryFree: gpu.controllers[0].memoryFree || 0 / 1024,
                },
                ram: {
                    total: ram.total / 1024 ** 3, // Convertir bytes en Go
                    free: ram.free / 1024 ** 3,
                    used: (ram.total - ram.free) / 1024 ** 3,
                },
                disk: {
                    size: disk[0].size / 1024 ** 3, // Convertir bytes en Go
                    // used: disk[0]. / 1024 ** 3,
                    // free: disk[0].free / 1024 ** 3,
                    type: disk[0].type,
                },
                network: {
                    speed: network[0].ms,
                    interface: network[0].iface,
                },
            };
        });
    }
    /**
     * Teste la performance du processeur en mode multithread en utilisant plusieurs cœurs.
     * @returns {Promise<number>} La performance du processeur en multithread (unité arbitraire)
     */
    static testMultiThreadPerformance() {
        return __awaiter(this, void 0, void 0, function* () {
            const cpu = yield si.cpu();
            const numCores = cpu.cores || 1; // Utiliser 4 cœurs pour le test
            const workerPromises = [];
            // Création d'un tableau de promises de workers
            for (let i = 0; i < numCores; i++) {
                workerPromises.push(new Promise((resolve, reject) => {
                    const worker = new node_worker_threads_1.Worker("./dist/worker.js"); // Exécuter le code du worker
                    worker.on("message", (result) => {
                        resolve(result);
                        worker.terminate();
                    });
                    worker.on("error", reject);
                    worker.postMessage(i);
                }));
            }
            // Attendre que tous les workers finissent leur tâche
            const results = yield Promise.all(workerPromises);
            const totalPerformance = results.reduce((sum, result) => sum + result, 0);
            return totalPerformance;
        });
    }
}
exports.SystemTester = SystemTester;
//# sourceMappingURL=index.js.map